#
# spec file for package itinerary
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           itinerary
Version:        21.12.3
Release:        bp154.1.46
Summary:        Itinerary and boarding pass management application
License:        LGPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://apps.kde.org/itinerary
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  breeze5-icons
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5Holidays)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5QQC2DeskopStyle)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KOSMIndoorMap)
BuildRequires:  cmake(KPimItinerary)
BuildRequires:  cmake(KPimPkPass)
BuildRequires:  cmake(KPublicTransport)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Location)
BuildRequires:  cmake(Qt5Positioning)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickCompiler)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(zlib)
# QML imports
Requires:       kirigami2
Requires:       prison-qt5-imports
# Runtime dependencies (itinerary won't start without these packages)
Requires:       kopeninghours
Requires:       kosmindoormap
Requires:       kpublictransport

%description
Itinerary and boarding pass management application.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

# Should be Utility Maps, but the checker does not like it
%suse_update_desktop_file org.kde.itinerary Education Geography
install -m0644 -D %{_kf5_iconsdir}/breeze/actions/22/map-globe.svg \
  %{buildroot}%{_kf5_iconsdir}/hicolor/22x22/actions/map-globe.svg

%check
# one test fails on ppc64 (be). Upstream is investigating
%ifnarch ppc64
%ctest
%endif

%if %{with released}
%find_lang %{name} --all-name
%endif

%if %{with released}
%files lang -f %{name}.lang
%endif

%files
%license LICENSES/*
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde
%{_kf5_applicationsdir}/org.kde.itinerary.desktop
%{_kf5_appstreamdir}/org.kde.itinerary.appdata.xml
%{_kf5_bindir}/itinerary
%{_kf5_debugdir}/org_kde_itinerary.categories
%{_kf5_iconsdir}/hicolor/
%{_kf5_libdir}/libSolidExtras.so
%{_kf5_notifydir}/itinerary.notifyrc
%{_kf5_qmldir}/org/kde/solidextras/

%changelog
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Format user visible numbers using the current locale
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Add 21.12.2 release notes
  * Add 21.12.1 release notes
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Don't break the timeline page when leaving development mode
  * Also make unit tests work against older KF versions without KI18nLocaleData
  * Fix station map platforms being mis-detected without live data
  * Get at least one live data update even for far future elements
  * Add 21.12.0 release notes
  * Fix ASAN unit test failure on the CI
  * Sanity-check model indexes
  * Fix certificate ordering when facing invalid dates
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Remove CI from stable branch again
  * Add CI for real
  * Enable new GitLab CI on stable branch.
  * Fix trend icon sizes on the statistics page
  * Also round the journey query delegate header background
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Also hide the issuer field when not present
  * Don't color health certificates without a verified signature green
  * NL CoronaCheck certificates specify no birth year, show that correctly
  * Handle fields not provided by the NL CoronaCheck certificates
  * Hide the health certificate swipe view when there are no certificates
  * Fix opening attached documents
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Add PDF417 barcode support for tickets (kde#444324)
  * Fix driving side warning for left-side driving countries (kde#440728)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Include iso-codes data files needed by KF::I18n 5.88
  * [EventDelegate] Hide location name if there is none
  * [Delegates] Use preferredWidth instead of width
  * Prevent map panning in the location picker switching to the previous page
  * For departureCountry check departureLocation
  * Don't let checkbox labels force the minimum page width (kde#443200)
  * Add 21.08.2 changelog
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Too many changes since 21.08.1, only listing bugfixes:
  * Also word-wrap welcome page headers (kde#443200)
  * Fix timeline model test breaking during the last hour of the day (kde#442821)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Properly encode mail attachments received via FairEmail share intents
  * Rename icon according to Flatpak convention
  * Add breeze as fallback icon theme
  * Add 21.08.0 changelog
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Tue Aug  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add more runtime requirements.
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Too many changes to list here.
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes to list here.
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Hotfix for upcoming CardListView changes in Kirigami 5.84
  * Add content rating to appstream data
  * Fix line breaks in departure view disruption notes
  * Force using org.kde.desktop style on non-Android
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix application version display in tarball builds
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Exclude kde5_xml_mimetypes.qm from the APK
  * Wrap overly long event venue names
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Exclude a few more translation catalogs we don't need
  * Give the country combo box enough space
  * Complete the exclusion list for all iso-codes catalogs we don't need
  * Set the APK version based on what is defined in CMake
  * Extend the asset ignore pattern
  * Don't install files we don't need on Android
  * Refine the packaging exclusion list
  * Add APK exclusion lists for libraries and assets
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
- Drop upstream patch:
  * Update-weather-API-endpoint.patch
* Fri Mar  5 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patch:
  * Update-weather-API-endpoint.patch
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Properly handle journey section begins/ends when setting platform names
  * Make tests independent of locale configuration
  * Align transfer and journey query pages
  * Port timeline delegates away from QtQuick layouts
  * Explicitly anchor address label to the left
  * Fix opening the indoor map for elements that aren't location changes
* Thu Dec 10 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Add a category to the desktop file (kde#429114)
  * Fix build with older CMake versions
- Drop upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- itinerary is now released using the KDE release service.
- Add upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Tue Jul 23 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
